{ config, lib, pkgs, ... }:
let
  kahulm = pkgs.callPackage ./package.nix { };
  cfg = config.services.kahulm;
in
{
  meta.maintainers = with lib.maintainers; [ soyouzpanda ];

  options.services.kahulm = {
    enable = lib.mkEnableOption "Kahulm";

    port = lib.mkOption {
      type = lib.types.int;
    };

    baseUrl = lib.mkOption {
      type = lib.types.str;
      default = "http://localhost:${builtins.toString cfg.port}";
    };

    sessionSecretFile = lib.mkOption {
      type = lib.types.nullOr lib.types.str;
      default = null;
    };
  };

  config = lib.mkIf cfg.enable {
    systemd.services.kahulm = {
      description = "Kahulm";

      wantedBy = [ "multi-user.target" ];
      after = [ "network.target" ];

      serviceConfig = {
        RuntimeDirectory = "kahulm";
        StateDirectory = "kahulm";
        WorkingDirectory = kahulm;
        Restart = "always";
        DynamicUser = true;
        Type = "exec";
        ProtectHome = true;
        ProtectSystem = "strict";
        PrivateTmp = true;
        PrivateDevices = true;
        ProtectHostname = true;
        ProtectClock = true;
        ProtectKernelTunables = true;
        ProtectKernelModules = true;
        ProtectKernelLogs = true;
        ProtectControlGroups = true;
        NoNewPrivileges = true;
        RestrictRealtime = true;
        RestrictSUIDSGID = true;
        RemoveIPC = true;
        PrivateMounts = true;
        LoadCredential = [
          "secret:${cfg.sessionSecretFile}"
        ];
      };

      environment = {
        PORT = builtins.toString cfg.port;
        BASE_URL = cfg.baseUrl;
        DB_FILE = "/var/lib/kahulm/db.sqlite";
      };

      script = ''
        export SESSION_SECRET=$(cat "''${CREDENTIALS_DIRECTORY}/secret")
        if [[ ! -f /var/lib/kahulm/db.sqlite ]]; then
          cp ${kahulm}/kahulm.sqlite /var/lib/kahulm/db.sqlite
        fi
        ${pkgs.nodejs}/bin/node ${kahulm}/dist/index.js
      '';
    };
  };
}
