(function(){
  "use strict";

  /*
   This code ensures that at least one choice is selected before submitting your answer.
   Moreover, when no choice is selected, it disable the submit button and adds a required
   attribute to all checkboxes (so the browser will prevent to submit the form).
   */

  let submitBtn = null;
  let choiceCheckboxes = [];

  function checkboxClicked() {
    const noneChecked = choiceCheckboxes.every((checkbox) => !checkbox.checked);
    if (noneChecked) {
      choiceCheckboxes.forEach((checkbox) => checkbox.setAttribute('required', ''));
      submitBtn.setAttribute('disabled', '');
    } else {
      choiceCheckboxes.forEach((checkbox) => checkbox.removeAttribute('required'));
      submitBtn.removeAttribute('disabled');
    }
  }

  document.addEventListener('DOMContentLoaded', () => {
    submitBtn = document.getElementById('submitBtn');
    choiceCheckboxes = Array.from(document.getElementsByClassName('choice'));
    for (let choiceCheckbox of choiceCheckboxes) {
      choiceCheckbox.addEventListener('click', checkboxClicked);
    }});
})();
