interface PaginationOptions {
  recordsPerPage?: number;
  maxVisiblePages?: number;
}

export function pagination(currentPage: number, recordsCount: number, options?: PaginationOptions) {
  const maxVisiblePages = options?.maxVisiblePages || 3;
  const usersPerPage = options?.recordsPerPage || 5;

  const pageCount = Math.ceil(recordsCount / usersPerPage);
  const firstVisiblePage = Math.max(1, currentPage - Math.floor(maxVisiblePages / 2));
  const lastVisiblePage = Math.min(firstVisiblePage + maxVisiblePages, pageCount);
  let visiblePages = [];
  for (let i = firstVisiblePage; i <= lastVisiblePage; ++i)
    visiblePages.push(i);

  return {
    current: currentPage,
    visiblePages,
    next: currentPage < pageCount ? currentPage + 1 : undefined,
    previous: currentPage > 0 ? currentPage - 1 : undefined,
  };
}
